@@ -1,7 +1,7 @@
 censor.vrat.x <-
 function(delta,x,min.branch){
 	x[x==0] <- min.branch
-	est <- optim(c(2,1),min.vrat, delta=delta, x=x)
+	est <- optim(c(1,1),min.vrat, NULL, delta=delta, x=x,method="L-BFGS-B",lower=c(1,1e-10))
 	par <- est$par
 	LL <- -est$value
 	
