@@ -1,7 +1,7 @@
 tree.na.Count <-
 function(tree,thr=6,srt="drop",min.val=0.01,mod.id=c(1,0,0,0)){
 	N=length(tree$edge.l)
-	subs=subtrees(tree)
+	subs=subtrees2.6(tree)
 	X <- 0
 	for(i in 1:(N/2)){
 	sZ<-length(subs[[i]]$edge.length)
